@@ -67,7 +67,7 @@ pub fn prepare_home(directory:&str)->String {
     path
 }
 
-/// Convert ';' list `Result<String, VarError>` into Vec<String>
+/// Convert ':' list `Result<String, VarError>` into Vec<String>
 #[allow(dead_code)]
 pub fn convert_to_vec(list:Result<String, VarError>)-> Vec<String> {
     let mut result:Vec<String> = vec![];
@@ -137,6 +137,19 @@ pub fn trash()->Result<String, VarError> {
     Ok(String::from(""))
 }
 
+/// Search the XDG data dirs vector for a `filename` in a `directory`
+pub fn search_data_dirs(filename:String, directory:&str) -> String {
+    for dir in data_dirs_vec(directory.to_string()) {
+        let mut tester = dir.to_owned();
+        tester.push_str("/");
+        tester.push_str(filename.as_str());
+        if Path::new(tester.as_str()).is_file(){
+            return tester.to_owned()
+        }
+    }
+    "".to_string()
+}
+
 /// loop xdg data dirs
 #[allow(dead_code)]
 pub fn loop_data_dirs(directory:String)->Result<String, VarError> {
@@ -194,19 +207,73 @@ pub fn data_dirs_vec(directory:String)->Vec<String> {
     result.dedup();
     result
 }
+/// loop xdg config dirs
+#[allow(dead_code)]
+pub fn loop_config_dirs(directory:String)->Result<String, VarError> {
+    let mut result = String::from("");
+    let result2 = config_dirs();
+    let mut fail = false;
+    if result2.is_ok() {
+        let res_list = result2.unwrap().to_owned();
+        for item in res_list.split(':') {
+            let mut tmp_path:String = item.to_owned();
+            tmp_path.push_str(directory.as_str());
+            if Path::new(tmp_path.as_str()).is_dir() {
+                tmp_path.push_str(":");
+                result.push_str(tmp_path.as_str());
+            }
+        }
+    }
+    else { fail = true;}
+    let home_dir = config_home();
+    if home_dir.is_ok() {
+        let mut d = home_dir.unwrap().to_owned();
+        d.push_str(directory.as_str());
+        if Path::new(d.as_str()).is_dir() {
+            d.push_str(":");
+            result.push_str(d.as_str());
+            fail = false;
+        }
+    }
+    else {fail = true;}
+    if fail {return Err(VarError::NotPresent)}
+    Ok(result)
+}
 /// The /menu directory
 #[allow(dead_code)]
 pub fn menu()->Result<String, VarError> {
-    let result = config_dirs();
-    let mut retval:String = "".to_string();
-    if result.is_ok() {
-        retval = result.unwrap().to_owned();
-        retval.push_str("/menu");
+    loop_config_dirs("/menus".to_string())
+}
+/// The session's menu file, based on `${XDG_MENU_PREFIX}`
+#[allow(dead_code)]
+pub fn session_menu_file()->Option<String> {
+    let menu = match menu() {
+        Ok(menu) => menu,
+        Err(e) => {
+            println!("Error:{}", e);
+            return None;
+        },
+    };
+    let xdg_menu_prefix = match env::var("XDG_MENU_PREFIX") {
+        Ok(prefix) => prefix,
+        Err(_e) => String::from(""),
+    };
+    let app_menu = "applications.menu";
+    let input = match loop_config_dirs("/menus".to_string()) {
+        Ok(input) => input,
+        Err(e) => return None,
+    };
+    let str_res:Vec<&str> = input.split(':').collect();
+    for item in str_res {
+        let mut s_item:String = item.to_owned();
+        s_item.push_str("/");
+        s_item.push_str(xdg_menu_prefix.as_str());
+        s_item.push_str(app_menu);
+        if Path::new(s_item.as_str()).is_file(){
+            return Some(s_item)
+        }
     }
-    if Path::new(retval.as_str()).is_dir() {
-        return Ok(retval)
-    }
-    return Err(VarError::NotPresent)
+    None
 }
 /// the /menu/applications-merged directory
 #[allow(dead_code)]
@@ -228,19 +295,23 @@ pub fn menu_merged()->Result<String, VarError> {
 pub fn applications()->Result<String, VarError> {
     loop_data_dirs("/applications".to_string())
 }
-/// DESKTOP DIRECTORIES, DIRECTORIES
+/// Desktop directories, directories
 #[allow(dead_code)]
 pub fn desktop_directories()->Result<String, VarError> {
     loop_data_dirs("/desktop-directories".to_string())
 }
-
+/// Desktop directories, directories vector
+#[allow(dead_code)]
+pub fn desktop_directories_vec()->Vec<String> {
+    data_dirs_vec("/desktop-directories".to_string())
+}
 /// 
 #[allow(dead_code)]
 pub fn autostart()->Result<String, VarError> {
     loop_data_dirs("/autostart".to_string())
 }
 
-/// ICON DIRECTORIES
+/// Icon directories
 #[allow(dead_code)]
 pub fn icon_dirs()->Result<String, VarError> {
     let result = home();
